rewrite_command

Function rewrite_command 

pub fn rewrite_command(command: &str) -> Option<String>
Attempt to rewrite a shell command to use tsift. Returns Some(rewritten) if applicable, None if no match.

pub (not pub(crate)) so the tsift-sim-world test-harness crate can exercise the rewrite surface as a dev-dependency.